##  Overview
The AI governance extension to the meta model lets you effectively track, manage, and categorize AI usage and risk. It helps you adopt best practices for modeling AI in your workspace for both commercial off-the-shelf (COTS) and self-built software.
To learn how to implement AI governance and adoption practices in SAP LeanIX using the extension, see [AI Governance and Adoption](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to implement AI governance practices in SAP LeanIX.").
